@@ -22,16 +22,20 @@
 
 #include <QCoreApplication>
 #include <QFileInfo>
+#include <QList>
+#include <QMimeDatabase>
 #include <QTextCodec>
 #include <QTextStream>
-#include <QList>
-#include <kmimetype.h>
-#include <kfileitem.h>
-#include <kfilemetainfo.h>
+ 
+#include <KFileItem>
 #include <KLocalizedString>
-#include <kmessagebox.h>
-#include <kstandarddirs.h>
-#include <kzip.h>
+#include <KMessageBox>
+#include <KZip>
+
+#include <KFileMetaData/Extractor>
+#include <KFileMetaData/ExtractorCollection>
+#include <KFileMetaData/PropertyInfo>
+#include <KFileMetaData/SimpleExtractionResult>
 
 KQuery::KQuery(QObject *parent)
     : QObject(parent)
@@ -47,14 +51,14 @@ KQuery::KQuery(QObject *parent)
     , m_regexpForContent(false)
     , m_useLocate(false)
     , m_showHiddenFiles(false)
-    , job(0)
+    , job(nullptr)
     , m_insideCheckEntries(false)
     , m_result(0)
 {
     processLocate = new KProcess(this);
-    connect(processLocate, SIGNAL(readyReadStandardOutput()), this, SLOT(slotreadyReadStandardOutput()));
-    connect(processLocate, SIGNAL(readyReadStandardError()), this, SLOT(slotreadyReadStandardError()));
-    connect(processLocate, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(slotendProcessLocate(int,QProcess::ExitStatus)));
+    connect(processLocate, &KProcess::readyReadStandardOutput, this, &KQuery::slotreadyReadStandardOutput);
+    connect(processLocate, &KProcess::readyReadStandardError, this, &KQuery::slotreadyReadStandardError);
+    connect(processLocate, QOverload<int, QProcess::ExitStatus>::of(&KProcess::finished), this, &KQuery::slotendProcessLocate);
 
     // Files with these mime types can be ignored, even if
     // findFormatByFileContent() in some cases may claim that
@@ -129,10 +133,9 @@ void KQuery::start()
             job = KIO::listDir(m_url, KIO::HideProgressInfo);
         }
 
-        connect(job, SIGNAL(entries(KIO::Job *,KIO::UDSEntryList)),
-                SLOT(slotListEntries(KIO::Job *,KIO::UDSEntryList)));
-        connect(job, SIGNAL(result(KJob *)), SLOT(slotResult(KJob *)));
-        connect(job, SIGNAL(canceled(KJob *)), SLOT(slotCanceled(KJob *)));
+        connect(job, SIGNAL(entries(KIO::Job*,KIO::UDSEntryList)),
+                SLOT(slotListEntries(KIO::Job*,KIO::UDSEntryList)));
+        connect(job, &KIO::ListJob::result, this, &KQuery::slotResult);
     }
 }
 
@@ -144,19 +147,9 @@ void KQuery::slotResult(KJob *_job)
     job = nullptr;
 
     m_result = _job->error();
-    checkEntries();
-}
-
-void KQuery::slotCanceled(KJob *_job)
-{
-    if (job != _job) {
-        return;
+    if (m_result == KIO::ERR_USER_CANCELED) {
+        m_fileItems.clear();
     }
-    job = nullptr;
-
-    m_fileItems.clear();
-
-    m_result = KIO::ERR_USER_CANCELED;
     checkEntries();
 }
 
@@ -207,7 +200,7 @@ void KQuery::checkEntries()
         emit foundFileList(m_foundFilesList);
     }
 
-    if (job == 0) {
+    if (job == nullptr) {
         emit result(m_result);
     }
 
@@ -225,7 +218,7 @@ void KQuery::slotListEntries(QStringList list)
 
     m_foundFilesList.clear();
     for (; it != end; ++it) {
-        processQuery(KFileItem(KFileItem::Unknown, KFileItem::Unknown, QUrl::fromLocalFile(*it)));
+        processQuery(KFileItem(QUrl::fromLocalFile(*it)));
     }
 
     if (!m_foundFilesList.isEmpty()) {
@@ -356,19 +349,29 @@ void KQuery::processQuery(const KFileItem &file)
             return;
         }
 
-        KFileMetaInfo metadatas(filename);
-        QStringList metakeys;
+        QMimeDatabase mimeDb;
+        QString mimetype = mimeDb.mimeTypeForFile(filename).name();
         QString strmetakeycontent;
 
-        metakeys = metadatas.supportedKeys();
-        for (QStringList::const_iterator it = metakeys.constBegin(); it != metakeys.constEnd(); ++it) {
-            if (!metaKeyRx.exactMatch(*it)) {
-                continue;
-            }
-            strmetakeycontent = metadatas.item(*it).value().toString();
-            if (strmetakeycontent.indexOf(m_metainfo) != -1) {
-                foundmeta = true;
-                break;
+        KFileMetaData::ExtractorCollection extractors;
+        QList<KFileMetaData::Extractor*> exList = extractors.fetchExtractors(mimetype);
+
+        Q_FOREACH (KFileMetaData::Extractor* ex, exList) {
+            KFileMetaData::SimpleExtractionResult result(filename, mimetype,
+                                                         KFileMetaData::ExtractionResult::ExtractMetaData);
+            ex->extract(&result);
+
+            KFileMetaData::PropertyMap properties = result.properties();
+            KFileMetaData::PropertyMap::const_iterator it = properties.constBegin();
+            for (; it != properties.constEnd(); it++) {
+                if (!metaKeyRx.exactMatch(KFileMetaData::PropertyInfo(it.key()).displayName())) {
+                    continue;
+                }
+                strmetakeycontent = it.value().toString();
+                if (strmetakeycontent.indexOf(m_metainfo) != -1) {
+                    foundmeta = true;
+                    break;
+                }
             }
         }
         if (!foundmeta) {
@@ -395,7 +398,7 @@ void KQuery::processQuery(const KFileItem &file)
         // FIXME: doesn't work with non local files
 
         QString filename;
-        QTextStream *stream = 0;
+        QTextStream *stream = nullptr;
         QFile qf;
         QRegExp xmlTags;
         QByteArray zippedXmlFileContent;
@@ -430,8 +433,17 @@ void KQuery::processQuery(const KFileItem &file)
             }
         } else if (!m_search_binary && !file.mimetype().startsWith(QLatin1String("text/"))
                    && file.url().isLocalFile() && !file.url().path().startsWith(QLatin1String("/dev"))) {
-            if (KMimeType::isBinaryData(file.url().path())) {
-                return;
+            QFile binfile(file.url().toLocalFile());
+            if (!binfile.open(QIODevice::ReadOnly)) {
+                return; // err, whatever
+            }
+            // Check the first 128 bytes (see shared-mime spec)
+            const QByteArray bindata = binfile.read(128);
+            const char* pbin = bindata.data();
+            const int end = qMin(128, bindata.size());
+            for (int i = 0; i < end; ++i) {
+                if ((unsigned char)(pbin[i]) < 32 && pbin[i] != 9 && pbin[i] != 10 && pbin[i] != 13) // ASCII control character
+                    return;
             }
         }
 
